# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-04-16 08:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0009_auto_20190304_1458'),
    ]

    operations = [
        migrations.CreateModel(
            name='BusinessProvider',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('fee', models.PositiveIntegerField(default='0')),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
        migrations.RemoveField(
            model_name='project',
            name='businessProviderFee',
        ),
        migrations.RemoveField(
            model_name='project',
            name='businessProvider',
        ),
        migrations.AddField(
            model_name='project',
            name='businessProvider',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='djangoldp_project.BusinessProvider'),
        ),
    ]



from django.conf import settings
from django.db import models

from djangoldp.models import Model


class Customer(Model):
    name = models.CharField(max_length=255, default='')
    address = models.CharField(max_length=255, default='')
    logo = models.URLField()
    companyRegister = models.CharField(default='', max_length=255)
    firstName = models.CharField(default='', max_length=255)
    lastName = models.CharField(default='', max_length=255)
    role = models.CharField(max_length=255, blank=True, null=True)
    email = models.EmailField(default='')
    phone = models.CharField(max_length=255, blank=True, null=True)

    def __str__(self):
        return self.name


class BusinessProvider(Model):
    name = models.CharField(max_length=255, default='')
    fee = models.PositiveIntegerField(default='0')

    def __str__(self):
        return self.name


class Project(Model):
    name = models.CharField(max_length=255, default='')
    description = models.CharField(max_length=255, default='')
    number = models.PositiveIntegerField(default='0', blank=True)
    creationDate = models.DateField(auto_now_add=True)
    customer = models.ForeignKey(Customer, on_delete=models.DO_NOTHING)  # WARN add import
    team = models.ManyToManyField(settings.AUTH_USER_MODEL, through='Member', blank=True)
    businessProvider = models.ForeignKey(BusinessProvider, blank=True, null=True, on_delete=models.DO_NOTHING)
    jabberID = models.CharField(max_length=255, blank=True, null=True)
    jabberRoom = models.BooleanField(default=True)

    class Meta:
        nested_fields = ['team', 'customer', 'members']
        default_permissions = ('add', 'change', 'delete', 'view', 'control')
        rdf_type = 'hd:project'
        depth = 0

    def __str__(self):
        return self.name


class Member(Model):
    project = models.ForeignKey(Project, on_delete=models.CASCADE, related_name='members')
    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name


Member._meta.container_path = "project-members/"



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-23 09:52
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_project', '0004_auto_20190121_1544'),
    ]

    operations = [
        migrations.CreateModel(
            name='Member',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
            ],
        ),
        migrations.RemoveField(
            model_name='job',
            name='project',
        ),
        migrations.RemoveField(
            model_name='job',
            name='user',
        ),
        migrations.AlterField(
            model_name='project',
            name='team',
            field=models.ManyToManyField(blank=True, through='djangoldp_project.Member', to=settings.AUTH_USER_MODEL),
        ),
        migrations.DeleteModel(
            name='Job',
        ),
        migrations.AddField(
            model_name='member',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='members', to='djangoldp_project.Project'),
        ),
        migrations.AddField(
            model_name='member',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-12-20 09:39
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('djangoldp_project', '0001_initial'),
    ]

    operations = [

    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-23 14:51
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0005_auto_20190123_0952'),
    ]

    operations = [
        migrations.RenameField(
            model_name='customer',
            old_name='name',
            new_name='companyName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactMail',
            new_name='email',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactFirstName',
            new_name='firstName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactLastName',
            new_name='lastName',
        ),
        migrations.RenameField(
            model_name='customer',
            old_name='contactPhone',
            new_name='phone',
        ),
        migrations.AddField(
            model_name='customer',
            name='role',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='creationDate',
            field=models.DateField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-03-04 10:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0007_auto_20190123_1459'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='member',
            options={'permissions': (('view_project', 'Read'), ('control_project', 'Control'))},
        ),
        migrations.AlterField(
            model_name='project',
            name='jabberRoom',
            field=models.BooleanField(default=True),
        ),
    ]
